@@ -8,11 +8,11 @@ from dateutil import rrule
 from itertools import groupby
 from cached_property import cached_property
 
-from trytond.model import Workflow, ModelSQL, ModelView, fields
+from trytond.model import Workflow, ModelSQL, ModelView, fields, Unique
 from trytond.pyson import Eval, Bool, If
 from trytond.pool import Pool
 from trytond.transaction import Transaction
-from trytond.wizard import (Wizard, StateView, StateTransition, StateAction,
+from trytond.wizard import (Wizard, StateView, StateTransition, StateReport,
     Button)
 from trytond.tools import grouped_slice
 from trytond.modules.company import CompanyReport
@@ -170,8 +170,9 @@ class Asset(Workflow, ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Asset, cls).__setup__()
+        table = cls.__table__()
         cls._sql_constraints = [
-            ('invoice_line_uniq', 'UNIQUE(supplier_invoice_line)',
+            ('invoice_line_uniq', Unique(table, table.supplier_invoice_line),
                 'Supplier Invoice Line can be used only once on asset.'),
             ]
         cls._error_messages.update({
@@ -994,7 +995,7 @@ class PrintDepreciationTable(Wizard):
             Button('Cancel', 'end', 'tryton-cancel'),
             Button('Print', 'print_', 'tryton-print', default=True),
             ])
-    print_ = StateAction('account_asset.report_depreciation_table')
+    print_ = StateReport('account.asset.depreciation_table')
 
     def do_print_(self, action):
         pool = Pool()
